@@ -27,6 +27,6 @@ def cli(ctx):
     do_cli(ctx.region, ctx.profile)  # pragma: no cover
 
 
-def do_cli(region, profile):
+def do_cli(region, profile):  # pragma: no cover
     bucket_name = bootstrap.manage_stack(profile=profile, region=region)
     click.echo("Source Bucket: " + bucket_name)
