@@ -9,7 +9,7 @@ from collections import OrderedDict
 from collections.abc import Callable, Mapping, MutableMapping
 from copy import deepcopy
 from enum import Enum
-from typing import List, Any, Dict, Iterator, Optional
+from typing import List, Any, Dict, Iterator, Optional, Union
 from uuid import uuid4
 import logging
 
@@ -322,7 +322,7 @@ class SimpleSectionItem(SectionItem):
     def value(self, value: Any) -> None:
         self._value = value
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return bool(self._value)
 
 
@@ -367,7 +367,7 @@ class DictSectionItem(SectionItem, MutableMapping):
     def extra_details(self, extra_details: Dict[str, Any]) -> None:
         self._extra_details = extra_details
 
-    def is_packageable(self):
+    def is_packageable(self) -> bool:
         """
         return if the resource is packageable
         """
@@ -396,7 +396,7 @@ class DictSectionItem(SectionItem, MutableMapping):
     def __iter__(self) -> Iterator:
         return iter(self._body)
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return bool(self._body)
 
 
@@ -422,7 +422,7 @@ class SimpleSection(Section):
     def value(self, value: Any) -> None:
         self._value = value
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return bool(self._value)
 
 
@@ -439,7 +439,7 @@ class DictSection(Section, MutableMapping):
         return deepcopy(self)
 
     @property
-    def section_items(self) -> List[DictSectionItem]:
+    def section_items(self) -> List[SectionItem]:
         return list(self._items_dict.values())
 
     def __setitem__(self, k: str, v: Any) -> None:
@@ -450,7 +450,8 @@ class DictSection(Section, MutableMapping):
                 "Resources": Resource,
                 "Parameters": Parameter,
             }
-            item_class = section_item_classes.get(self._section_name, DictSectionItem)
+            class_name = self._section_name or ""
+            item_class = section_item_classes.get(class_name, DictSectionItem)
             item = item_class(key=k, body=v)
             self._items_dict[k] = item
         else:
@@ -459,7 +460,7 @@ class DictSection(Section, MutableMapping):
     def __delitem__(self, v: str) -> None:
         del self._items_dict[v]
 
-    def __getitem__(self, k: str) -> DictSectionItem:
+    def __getitem__(self, k: str) -> Any:
         v = self._items_dict[k]
         if isinstance(v, SimpleSectionItem):
             return v.value
@@ -471,7 +472,7 @@ class DictSection(Section, MutableMapping):
     def __iter__(self) -> Iterator:
         return iter(self._items_dict)
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return bool(self._items_dict)
 
 
@@ -492,7 +493,7 @@ class Resource(DictSectionItem):
         self._nested_stack = nested_stack
         super().__init__(key, item_id, body, assets, extra_details)
 
-    def copy(self):
+    def copy(self) -> "Resource":
         return deepcopy(self)
 
     @property
@@ -521,7 +522,7 @@ class Parameter(DictSectionItem):
         self._added_by_iac = added_by_iac
         super().__init__(key, item_id, body, assets, extra_details)
 
-    def copy(self) -> "Resource":
+    def copy(self) -> "Parameter":
         return deepcopy(self)
 
     @property
@@ -608,7 +609,7 @@ class Stack(MutableMapping):
         return self._sections
 
     @property
-    def assets(self) -> Optional[List[Asset]]:
+    def assets(self) -> List[Asset]:
         return self._assets
 
     @assets.setter
@@ -638,13 +639,13 @@ class Stack(MutableMapping):
         }
         return any(isinstance(asset, package_type_to_asset_cls_map[package_type]) for asset in self.assets)
 
-    def get_overrideable_parameters(self):
+    def get_overrideable_parameters(self) -> Dict:
         """
         Return a dict of parameters that are override-able, i.e. not added by iac
         """
         return {key: val for key, val in self.get("Parameters", {}).items() if not val.added_by_iac}
 
-    def as_dict(self):
+    def as_dict(self) -> Union[MutableMapping, Mapping]:
         """
         return the stack as a dict for JSON serialization
         """
@@ -664,7 +665,7 @@ class Stack(MutableMapping):
     def __delitem__(self, v: str) -> None:
         del self._sections[v]
 
-    def __getitem__(self, k: str) -> Section:
+    def __getitem__(self, k: str) -> Any:
         v = self._sections[k]
         if isinstance(v, SimpleSection):
             return v.value
@@ -676,7 +677,7 @@ class Stack(MutableMapping):
     def __iter__(self) -> Iterator:
         return iter(self._sections)
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return bool(self._sections)
 
 
@@ -714,7 +715,7 @@ class SamCliProject:
     def extra_details(self, extra_details: Dict[str, Any]) -> None:
         self._extra_details = extra_details
 
-    def find_stack_by_name(self, name: str):
+    def find_stack_by_name(self, name: str) -> Optional["Stack"]:
         for stack in self.stacks:
             if stack.name == name:
                 return stack
@@ -771,7 +772,7 @@ class SamCliContext:
         self._region = region
 
     @property
-    def command_options_map(self):
+    def command_options_map(self) -> Dict[str, Any]:
         """
         the context retrieved from command line, its key is the command line option
         name, value is corresponding input
@@ -779,23 +780,23 @@ class SamCliContext:
         return self._command_options_map
 
     @property
-    def sam_command_name(self):
+    def sam_command_name(self) -> str:
         return self._sam_command_name
 
     @property
-    def is_guided(self):
+    def is_guided(self) -> bool:
         return self._is_guided
 
     @property
-    def is_debugging(self):
+    def is_debugging(self) -> bool:
         return self._is_debugging
 
     @property
-    def profile(self):
+    def profile(self) -> Optional[Dict[str, Any]]:
         return self._profile
 
     @property
-    def region(self):
+    def region(self) -> Optional[str]:
         return self._region
 
 
@@ -840,7 +841,7 @@ class IaCPluginInterface(metaclass=abc.ABCMeta):
         raise NotImplementedError
 
 
-def _make_dict(obj):
+def _make_dict(obj: Union[MutableMapping, Mapping]) -> Union[MutableMapping, Mapping]:
     if not isinstance(obj, MutableMapping):
         return obj
     to_return = dict()
