@@ -4,6 +4,12 @@ Class that provides functions from a given SAM template
 import logging
 from typing import Dict, List, Optional, cast, Iterator, Any
 
+from samcli.lib.utils.resources import (
+    AWS_LAMBDA_FUNCTION,
+    AWS_LAMBDA_LAYERVERSION,
+    AWS_SERVERLESS_FUNCTION,
+    AWS_SERVERLESS_LAYERVERSION,
+)
 from samcli.commands.local.cli_common.user_exceptions import InvalidLayerVersionArn
 from samcli.lib.providers.exceptions import InvalidLayerReference
 from samcli.lib.utils.colors import Colored
@@ -129,7 +135,7 @@ class SamFunctionProvider(SamBaseProvider):
                 if resource_metadata:
                     resource_properties["Metadata"] = resource_metadata
 
-                if resource_type in [SamFunctionProvider.SERVERLESS_FUNCTION, SamFunctionProvider.LAMBDA_FUNCTION]:
+                if resource_type in [AWS_SERVERLESS_FUNCTION, AWS_LAMBDA_FUNCTION]:
                     resource_package_type = resource_properties.get("PackageType", ZIP)
 
                     code_property_key = SamBaseProvider.CODE_PROPERTY_KEYS[resource_type]
@@ -144,15 +150,19 @@ class SamFunctionProvider(SamBaseProvider):
                             SamFunctionProvider._warn_code_extraction(resource_type, name, code_property_key)
                         continue
 
-                    if resource_package_type == IMAGE and SamBaseProvider._is_ecr_uri(
-                        resource_properties.get(image_property_key)
+                    if (
+                        resource_package_type == IMAGE
+                        and SamBaseProvider._is_ecr_uri(resource_properties.get(image_property_key))
+                        and not SamFunctionProvider._metadata_has_necessary_entries_for_image_function_to_be_built(
+                            resource_metadata
+                        )
                     ):
                         # ImageUri can be an ECR uri, which is not supported
                         if not ignore_code_extraction_warnings:
                             SamFunctionProvider._warn_imageuri_extraction(resource_type, name, image_property_key)
                         continue
 
-                if resource_type == SamFunctionProvider.SERVERLESS_FUNCTION:
+                if resource_type == AWS_SERVERLESS_FUNCTION:
                     layers = SamFunctionProvider._parse_layer_info(
                         stack,
                         resource_properties.get("Layers", []),
@@ -168,7 +178,7 @@ class SamFunctionProvider(SamBaseProvider):
                     )
                     result[function.full_path] = function
 
-                elif resource_type == SamFunctionProvider.LAMBDA_FUNCTION:
+                elif resource_type == AWS_LAMBDA_FUNCTION:
                     layers = SamFunctionProvider._parse_layer_info(
                         stack,
                         resource_properties.get("Layers", []),
@@ -344,6 +354,7 @@ class SamFunctionProvider(SamBaseProvider):
             metadata=metadata,
             inlinecode=inlinecode,
             codesign_config_arn=resource_properties.get("CodeSigningConfigArn", None),
+            architectures=resource_properties.get("Architectures", None),
         )
 
     @staticmethod
@@ -424,8 +435,8 @@ class SamFunctionProvider(SamBaseProvider):
         layer_logical_id = cast(str, layer.get("Ref"))
         layer_resource = stack.resources.get(layer_logical_id)
         if not layer_resource or layer_resource.get("Type", "") not in (
-            SamFunctionProvider.SERVERLESS_LAYER,
-            SamFunctionProvider.LAMBDA_LAYER,
+            AWS_SERVERLESS_LAYERVERSION,
+            AWS_LAMBDA_LAYERVERSION,
         ):
             raise InvalidLayerReference()
 
@@ -434,7 +445,7 @@ class SamFunctionProvider(SamBaseProvider):
         compatible_runtimes = layer_properties.get("CompatibleRuntimes")
         codeuri: Optional[str] = None
 
-        if resource_type in [SamFunctionProvider.LAMBDA_LAYER, SamFunctionProvider.SERVERLESS_LAYER]:
+        if resource_type in [AWS_LAMBDA_LAYERVERSION, AWS_SERVERLESS_LAYERVERSION]:
             code_property_key = SamBaseProvider.CODE_PROPERTY_KEYS[resource_type]
             if SamBaseProvider._is_s3_location(layer_properties.get(code_property_key)):
                 # Content can be a dictionary of S3 Bucket/Key or a S3 URI, neither of which are supported
@@ -460,3 +471,19 @@ class SamFunctionProvider(SamBaseProvider):
         if not candidates:
             raise RuntimeError(f"Cannot find resources with stack_path = {stack_path}")
         return candidates[0]
+
+    @staticmethod
+    def _metadata_has_necessary_entries_for_image_function_to_be_built(metadata: Optional[Dict[str, Any]]) -> bool:
+        """
+        > Note: If the PackageType property is set to Image, then either ImageUri is required,
+          or you must build your application with necessary Metadata entries in the AWS SAM template file.
+          https://docs.aws.amazon.com/serverless-application-model/latest/developerguide/sam-resource-function.html#sam-function-imageuri
+
+        When ImageUri and Metadata are both provided, we will try to determine whether to treat the function
+        as to be built or to be skipped. When we skip it whenever "ImageUri" is provided,
+        we introduced a breaking change https://github.com/aws/aws-sam-cli/issues/3239
+
+        This function is used to check whether there are the customers have "intention" to
+        let AWS SAM CLI to build this image function.
+        """
+        return isinstance(metadata, dict) and bool(metadata.get("DockerContext"))
