@@ -24,33 +24,46 @@ class FunctionConfig:
         packagetype,
         code_abs_path,
         layers,
+        architecture,
         memory=None,
         timeout=None,
         env_vars=None,
     ):
         """
-        Initialize the class.
-
         Parameters
         ----------
-        name str
+        name : str
             Name of the function
-        runtime str
+        runtime : str
             Runtime of function
-        handler str
+        handler : str
             Handler method
-        code_abs_path str
+        imageuri : str
+            Name of the Lambda Image which is of the form {image}:{tag}
+        imageconfig : str
+            Image configuration which can be used set to entrypoint, command and working dir for the container.
+        packagetype : str
+            Package type for the lambda function which is either zip or image.
+        code_abs_path : str
             Absolute path to the code
-        layers list(str)
+        layers : list(str)
             List of Layers
-        memory int
-            Function memory limit in MB
-        timeout int
-            Function timeout in seconds
-        env_vars samcli.local.lambdafn.env_vars.EnvironmentVariables
-            Optional, Environment variables.
-            If it not provided, this class will generate one for you based on the function properties
+        architecture : str
+            Architecture type either x86_64 or arm64 on AWS lambda
+        memory : int, optional
+            Function memory limit in MB, by default None
+        timeout : int, optional
+            Function timeout in seconds, by default None
+        env_vars : str, optional
+            Environment variables, by default None
+             If it not provided, this class will generate one for you based on the function properties
+
+        Raises
+        ------
+        InvalidSamTemplateException
+            Throw when template provided was invalid and not able to transform into a Standard CloudFormation Template
         """
+
         self.name = name
         self.runtime = runtime
         self.imageuri = imageuri
@@ -60,6 +73,7 @@ class FunctionConfig:
         self.code_abs_path = code_abs_path
         self.layers = layers
         self.memory = memory or self._DEFAULT_MEMORY
+        self.architecture = architecture
 
         self.timeout = timeout or self._DEFAULT_TIMEOUT_SECONDS
 
